<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML//EN">
<html>

<head>
<meta http-equiv="Content-Type"
content="text/html; charset=iso-8859-1">
<meta name="GENERATOR" content="Microsoft FrontPage 2.0">
<title>User Interface Localization Guidelines</title>
</head>

<body bgcolor="#FFFFFF">

<h1>User Interface Localization Guidelines</h1>

<h2>Introduction</h2>

<p>The Amiga community has always been uniquely active and
constructive. Several volunteers have contributed to the creation
of new user interface localizations for popular Cloanto packages
like Personal Paint, which are designed to work with easily
editable external localization modules. This document, inspired
by our internal translation guidelines, is dedicated to all the
volunteers who are helping Cloanto and other developers and users
with their passion and linguistical knowledge. It contains some
guidelines to simplify certain choices, avoid unnecessary work,
and ensure stylistical consistency and technical functionality.</p>

<h2>Style of Computer-User Interaction</h2>

<p>We do not wish to open a debate or write a book on man-machine
interaction. However, we have chosen to follow a specific style
in the way our software user interfaces communicate with the
user. We encourage all translators to be consistent with this style.</p>

<p>There are different viewpoints on how a computer should
communicate in a textual form with the user. We tend to disagree
with systems in which machines use the words &quot;I&quot; and
&quot;You&quot;, as in &quot;I just found an error here&quot;, or
&quot;You MUST do this&quot; (the use of capitals and imperatives
addressed to the user is also arguable). These are not abstract
examples: even the German Amiga OS complains that it
&quot;Bentige UNBEDINGT/wieder den Datentrger %s&quot;, where
&quot;Der Datentrger %s wird unbedingt bentigt&quot; could
have done the job. We do not like this use of the first person
because:</p>

<ul>
    <li>It is technically incorrect (all messages which are
        displayed were previously written by a programmer)</li>
</ul>

<ul>
    <li>It is philosophically incorrect (a computer has no
        &quot;I&quot;)</li>
</ul>

<ul>
    <li>It confuses and misleads most those users with less
        computer knowledge</li>
</ul>

<ul>
    <li>It is a step towards a potentially dangerous direction
        (not being able to tell the difference between a machine
        and another human being)</li>
</ul>

<p>While we are open-minded about a future in which the
difference between machines and self-conscious biological
entities blurs away, for our current software we prefer messages
like &quot;An error was found in...&quot;, or &quot;This can be
done by...&quot;, in which the style is self-descriptive,
impersonal, and attention is focussed on the action or the
message object. For messages, please try to use a style in which
actions become the subject or the object. The computer does not
&quot;speak&quot; in the first person, e.g.: not &quot;I will
delete the text&quot;, or &quot;You will loose the text&quot;,
but &quot;The text will be lost&quot;. Writing in an impersonal
style may appear to be difficult at first (a bit like writing in
a genderless style, where an author does not use &quot;he or
she&quot; all the time), but once the basic constructions are
set, one tends to proceed very smoothly. For menus and commands,
try to formulate the texts so that the user does not select
actions in imperative form, if the language allows for
alternatives such as infinitive. It is not possible to briefly
set one rule for all languages: infinitives may do the job in one
language, whereas passives may be the standard in another. In any
case, consistency has priority: please use only one style. Prefer
clear, simple, short sentences wherever possible. </p>

<p>If there is no way but to have the computer address the user
with an imperative, <em>please</em> do not forget that there are
words like &quot;please&quot;. Style is also a matter of...
style. If the user is to be addressed directly, the most formal
and polite of all courtesy forms should be considered (e.g.
German &quot;Sie&quot; or Italian &quot;Voi&quot;, but in these
languages it is easy to reformulate a sentence in an impersonal
way).</p>

<p>Style guides from companies like IBM, Apple and Microsoft are
very interesting reading. However, at least in some languages,
these companies have followed different directions. We think that
IBM often went too far in translating almost every single English
word in languages like Italian, creating new meanings for Italian
words which had a widely used English standard name. Apple, on
the other hand, often uses a style in which the computer speaks
in the first person as if it were the user's best friend. We
prefer to avoid these extremes, accepting the use of English
words which have no well-known local equivalent, and preferring
an impersonal style to an artificially friendly and personal
style.</p>

<p>We recommend to use the English user interface as a
translation basis, perhaps looking at various translations for
inspiration and consistency. When using the English texts as a
source, please note that the use of capital initials for words
appearing in titles is due to the English style of writing
titles, and is not applicable to all languages.</p>

<h2>Working on a New Translation</h2>

<p>Before beginning the translation, please make sure that you
are going to work with the latest version of the software. If you
do not have it, you can get one for free from us. We do offer
free software to all volunteers who participate in a new
localization. In any case, we would recommend to <a
href="mailto:support@cloanto.com">contact us</a> first, in order
to avoid possible duplications of efforts.</p>

<p>Once the translation is complete, we would ask that you send
it to us, rather than uploading it directly to sites such as
Aminet. This allows us to test it in different screen
resolutions, test the keyboard shortcuts, and create versions of
the same translation for older program versions, which we also
support. Then we will prepare all the files in a format
consistent with the other files, and upload everything to the
&quot;biz/cloan&quot; directory on Aminet. Your name and E-mail
address will remain in the &quot;Author&quot; field, and you will
also receive the latest version of Personal Paint from us.</p>

<p>If you do not wish your translation, your name and/or your
E-mail address to be freely distributed, please express this
explicitly.</p>

<h2>A Practical Example: Personal Paint</h2>

<p>This section explains some technical aspects of the user
interface files of Personal Paint. Amiga programs like ColorType,
Personal Fonts Maker 2 and Personal Write use similar formats.</p>

<p>To make the user interface files easily editable with standard
tools and compatible with all versions of the operating system,
we chose to store them as plain text files, instead of using the
Amiga locale format (which, by the way, was introduced after our
main packages were first released). For Personal Paint, these
files are stored in the &quot;PPaint_Prefs&quot; directory,
located in the program installation directory. The user interface
files are named &quot;UIText.<em>xxx</em>&quot;, where &quot;<em>xxx</em>&quot;
indicates a three-letter language suffix. Personal Paint 7
currently recognizes the following suffixes:</p>

<blockquote>
    <pre><strong>ID  LANGUAGE    SUFFIX</strong></pre>
    <pre>00  English     .eng
01  German      .deu
02  Italian     .ita
03  French      .fra
04  Spanish     .esp
05  Dutch       .hol
06  Swedish     .swe
07  Danish      .dan
08  Norwegian   .nor
09  Finnish     .fin
10  Portuguese  .prt
11  Polish      .pol
12  Hungarian   .hun
13  Czech       .cze
14  Slowak      .svk
15  Slovenian   .svn
16  Croatian    .hrv</pre>
    <pre>99  Custom      .custom</pre>
</blockquote>

<p>The &quot;.custom&quot; file name suffix is associated to the
menu item with the same name, which was designed to support
languages not defined by other suffixes. The ID value is used for
the LANG program setting, which is usually included in the
&quot;Startup_A.set&quot; startup setting file to determine the
program startup language. If the LANG parameter is not set, or if
it is set to 0xFFFFFFFF, then the software will try to run in the
current system default language, and fall back to the first
available language, in order of ID, if the desired language file
is not found.</p>

<p>Personal Paint, like most Cloanto applications, can change
user interface language while it is running. The software can
also reload the current language. This is useful for interactive
testing. When loading a user interface file, Personal Paint
performs some simple length-checks and issues warning messages to
indicate texts which are too long or should be made splittable.
While this feature is useful for quickly testing a file as it is
being edited, the only guarantee that the file will actually work
properly is to manually display all menus and requesters in the
lowest possible screen resolution (320200 for Personal Paint
and other graphics packages, 640200 for Personal Write). It is
also important to check that there are no conflicts with the
keyboard shortcuts in the various requesters, especially with
common gadgets like Proceed, OK and Cancel. </p>

<p>The user interface files can be loaded, modified and saved
again as plain text with any text editor or word processor (e.g.
with the &quot;Load Document&quot; command of Personal Write). If
Personal Write is used to edit the text, &quot;TAB step&quot;
should be set to 8, and &quot;TABs in output file&quot; should be
set to &quot;Automatic&quot;. Both are the default values for
these settings.</p>

<p>A few very important rules must be followed to create a new
file with the user interface texts. The easiest way to create
such a file is to use an existing file as a point of departure.
The file must be stored as a plain ASCII text file, without
control sequences. TAB characters separating the shortcuts from
the menu text must be preserved. Each line in the file must
contain either one or more valid texts (separated with TABs), a
comment, or no characters at all (blank line used as an optical
separator). Leading space and TAB characters are skipped.
Comments begin with a ';' (ASCII decimal code 59) sign and end at
the end of the line. Each line (including the last one) must
terminate with a LF character (ASCII code 10). </p>

<p>An optional keyboard suffix may be written, enclosed between
the &quot;&lt; &gt;&quot; (less than and greater than) signs and
separated by one or more TABs, after each menu item text. The
shortcut must be in the &lt;Qualifier-Key&gt; format. The
qualifier field is optional. The qualifiers which are supported
are: &quot;Shift&quot;, &quot;Alt&quot;, &quot;Ctrl&quot;,
&quot;Amiga&quot;, and &quot;Num&quot; (numeric keypad). For
example, &quot;&lt;Shift-Up&gt;&quot; would mean &quot;this
command should be executed by pressing the &lt;Cursor Up&gt; key
while &lt;Shift&gt; is held down.&quot; </p>

<p>The keyboard shortcuts at the end of the file are associated
to functions which have no menu-equivalent. </p>

<p>Double assignments of the same shortcut should be avoided, as
only one menu item can be associated with a key combination.
&lt;Ctrl&gt; and &lt;Alt&gt; have special meanings in in the
Screen Grab function and in combination with the left mouse
button. These local uses cannot be redefined. </p>

<p>&quot;Left&quot;, &quot;Right&quot;, &quot;Up&quot; and
&quot;Down&quot; are used to indicate the four cursor keys. Other
textual representations include: &quot;SP&quot;, &quot;Tab&quot;,
&quot;BS&quot;, &quot;Del&quot;, &quot;Help&quot;,
&quot;Esc&quot; and &quot;F1&quot; to &quot;F10&quot;. </p>

<p>When input by the user, lower case letters are treated
differently than capitals in cycle gadgets, proportional gadgets
and listviews. The former force the gadget to &quot;go
forward&quot;, while the latter make it &quot;go back&quot;. In
other gadget types, upper and lower case letters are treated as
identical. </p>

<p>&lt;Shift&gt; should not be used as a qualifier for keys which
already have a system-defined shifted representation (e.g.,
&lt;Shift-a&gt; is wrong, while &lt;A&gt; is correct). For
commands which must remain accessible in a text editing session,
only function key shortcuts and shortcuts having an &lt;Amiga&gt;
key qualifier should be used. Other keys would be interpreted as
a character to be typed, rather than a command to be executed. </p>

<p>The texts should be designed and tested in such a way that all
menus and requesters can be displayed in a low resolution screen
320 pixels wide and 200 lines tall. Message texts
(&quot;TMS&quot; section of the file) which exceed the horizontal
limit may be made &quot;splittable&quot; by inserting underscore
characters ('_') where Personal Paint may bring the text to a new
line, if necessary. Normally, these characters are automatically
replaced with spaces. </p>

<p>Due to the new Animation features, more menus have to share
the same horizontal screen space. The underscore character can be
used to indicate where a menu title text can be abbreviated (this
may be necessary when using low-resolution screen modes). For
example, the program could abbreviate &quot;Anim_ation&quot; to
&quot;Anim.&quot;, should this be necessary. Otherwise, the menu
would be displayed normally (&quot;Animation&quot;). </p>

<p>The underscore character can be used in sections TXW (window
texts) and TXG (gadget texts) of the user interface text files.
The character following the underscore will be underlined and
used as a keyboard shortcut, in accordance with the Amiga user
interface specifications. Supported gadget types are: cycle
gadgets, checkboxes, sliders, listviews (scrollboxes) and action
gadget texts (e.g. &quot;_OK&quot;). </p>

<p>The user interface text files contain a version number, used
to identify the release version of the text file. This number is
read by Personal Paint, and should normally not be changed.</p>
</body>
</html>
